@@ -10,7 +10,6 @@ from typing.io import BinaryIO
 import requests
 from google.cloud import storage, pubsub
 
-from ..config.logging import logger
 from ..config.settings import (
     GOOGLE_DOWNLOAD_ROLE,
     GOOGLE_UPLOAD_ROLE,
@@ -27,6 +26,9 @@ from ..config.settings import (
     DEV_CFUNCTIONS_SERVER,
     INACTIVE_USER_DAYS,
 )
+from ..config.logging import get_logger
+
+logger = get_logger(__name__)
 
 
 def _get_bucket(bucket_name: str) -> storage.Bucket:
@@ -70,7 +72,7 @@ def upload_xlsx_to_gcs(
     )
 
     if ENV == "dev":
-        logger().info(
+        logger.info(
             f"Would've saved {blob_name} to {GOOGLE_UPLOAD_BUCKET} and {GOOGLE_DATA_BUCKET}"
         )
         return _pseudo_blob(
@@ -95,15 +97,13 @@ def grant_upload_access(user_email: str):
     means a user can write objects to the bucket but cannot delete,
     overwrite, or read objects from this bucket.
     """
-    logger().info(f"granting upload to {user_email}")
+    logger.info(f"granting upload to {user_email}")
     bucket = _get_bucket(GOOGLE_UPLOAD_BUCKET)
 
     # Update the bucket IAM policy to include the user as an uploader.
     policy = bucket.get_iam_policy()
     policy[GOOGLE_UPLOAD_ROLE] = {*policy[GOOGLE_UPLOAD_ROLE], f"user:{user_email}"}
-    logger().info(
-        f"{GOOGLE_UPLOAD_ROLE} binding updated to {policy[GOOGLE_UPLOAD_ROLE]}"
-    )
+    logger.info(f"{GOOGLE_UPLOAD_ROLE} binding updated to {policy[GOOGLE_UPLOAD_ROLE]}")
     bucket.set_iam_policy(policy)
 
 
@@ -111,15 +111,13 @@ def revoke_upload_access(user_email: str):
     """
     Revoke a user's upload access for the given bucket.
     """
-    logger().info(f"revoking upload from {user_email}")
+    logger.info(f"revoking upload from {user_email}")
     bucket = _get_bucket(GOOGLE_UPLOAD_BUCKET)
 
     # Update the bucket IAM policy to remove the user's uploader privileges.
     policy = bucket.get_iam_policy()
     policy[GOOGLE_UPLOAD_ROLE].discard(f"user:{user_email}")
-    logger().info(
-        f"{GOOGLE_UPLOAD_ROLE} binding updated to {policy[GOOGLE_UPLOAD_ROLE]}"
-    )
+    logger.info(f"{GOOGLE_UPLOAD_ROLE} binding updated to {policy[GOOGLE_UPLOAD_ROLE]}")
     bucket.set_iam_policy(policy)
 
 
@@ -129,7 +127,7 @@ def grant_download_access(user_email: str, trial_id: str, upload_type: str):
     """
     url_prefix, prefix_expression = _build_prefix_clause(trial_id, upload_type)
 
-    logger().info(f"Granting download access on {url_prefix}* to {user_email}")
+    logger.info(f"Granting download access on {url_prefix}* to {user_email}")
 
     # get the current IAM policy for the data bucket
     bucket = _get_bucket(GOOGLE_DATA_BUCKET)
@@ -154,7 +152,7 @@ def revoke_download_access(user_email: str, trial_id: str, upload_type: str):
     """
     url_prefix, prefix_expression = _build_prefix_clause(trial_id, upload_type)
 
-    logger().info(f"Revoking download access on {url_prefix}* from {user_email}")
+    logger.info(f"Revoking download access on {url_prefix}* from {user_email}")
 
     # get the current IAM policy for the data bucket
     bucket = _get_bucket(GOOGLE_DATA_BUCKET)
@@ -309,7 +307,7 @@ def get_signed_url(
         method=method,
         response_disposition=f'attachment; filename="{full_filename}"',
     )
-    logger().info(f"generated signed URL for {object_name}: {url}")
+    logger.info(f"generated signed URL for {object_name}: {url}")
 
     return url
 
@@ -323,7 +321,7 @@ def _encode_and_publish(content: str, topic: str) -> Future:
     # Don't actually publish to Pub/Sub if running locally
     if ENV == "dev":
         if DEV_CFUNCTIONS_SERVER:
-            logger().info(
+            logger.info(
                 f"Publishing message {content!r} to topic {DEV_CFUNCTIONS_SERVER}/{topic}"
             )
             import base64
@@ -338,13 +336,13 @@ def _encode_and_publish(content: str, topic: str) -> Future:
                     f"Couldn't publish message {content!r} to topic {DEV_CFUNCTIONS_SERVER}/{topic}"
                 ) from e
             else:
-                logger().info(f"Got {res}")
+                logger.info(f"Got {res}")
                 if res.status_code != 200:
                     raise Exception(
                         f"Couldn't publish message {content!r} to {DEV_CFUNCTIONS_SERVER}/{topic}: {res!r}"
                     )
         else:
-            logger().info(f"Would've published message {content} to topic {topic}")
+            logger.info(f"Would've published message {content} to topic {topic}")
         return
 
     # The Pub/Sub publisher client returns a concurrent.futures.Future
@@ -389,7 +387,7 @@ def send_email(to_emails: List[str], subject: str, html_content: str, **kw):
     """
     # Don't actually send an email if this is a test
     if TESTING or ENV == "dev":
-        logger().info(f"Would send email with subject '{subject}' to {to_emails}")
+        logger.info(f"Would send email with subject '{subject}' to {to_emails}")
         return
 
     email_json = json.dumps(
